==> ideaIC-182.3208.16-sources.jar: com/intellij/openapi/vcs/checkout/CheckoutAction.java <==
/*
 * Copyright 2000-2015 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.openapi.vcs.checkout;

import com.intellij.internal.statistic.collectors.fus.actions.persistence.ActionIdProvider;
import com.intellij.openapi.actionSystem.AnAction;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.actionSystem.CommonDataKeys;
import com.intellij.openapi.project.DumbAware;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.project.ProjectManager;
import com.intellij.openapi.vcs.CheckoutProvider;
import com.intellij.openapi.vcs.ProjectLevelVcsManager;

public class CheckoutAction extends AnAction implements DumbAware, ActionIdProvider {
  private final CheckoutProvider myProvider;
  private final String myIdPrefix;

  public CheckoutAction(CheckoutProvider provider, String idPrefix) {
    super(provider.getVcsName());
    myProvider = provider;
    myIdPrefix = idPrefix;
  }

  public void actionPerformed(final AnActionEvent e) {
    Project project = e.getData(CommonDataKeys.PROJECT);
    project = (project == null) ? ProjectManager.getInstance().getDefaultProject() : project;
    myProvider.doCheckout(project, getListener(project));
  }

  protected CheckoutProvider.Listener getListener(Project project) {
    return ProjectLevelVcsManager.getInstance(project).getCompositeCheckoutListener();
  }

  @Override
  public String getId() {
    return myIdPrefix + "." + myProvider.getVcsName().replaceAll("_", "");
  }
}

==> ideaIC-2018.3.3-sources.jar: com/intellij/openapi/vcs/checkout/CheckoutAction.java <==
// Copyright 2000-2018 JetBrains s.r.o. Use of this source code is governed by the Apache 2.0 license that can be found in the LICENSE file.
package com.intellij.openapi.vcs.checkout;

import com.intellij.internal.statistic.collectors.fus.actions.persistence.ActionIdProvider;
import com.intellij.openapi.actionSystem.AnAction;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.actionSystem.CommonDataKeys;
import com.intellij.openapi.project.DumbAware;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.project.ProjectManager;
import com.intellij.openapi.vcs.CheckoutProvider;
import com.intellij.openapi.vcs.ProjectLevelVcsManager;
import org.jetbrains.annotations.NotNull;

public class CheckoutAction extends AnAction implements DumbAware, ActionIdProvider {
  private final CheckoutProvider myProvider;
  private final String myIdPrefix;

  public CheckoutAction(CheckoutProvider provider, String idPrefix) {
    super(provider.getVcsName());
    myProvider = provider;
    myIdPrefix = idPrefix;
  }

  @Override
  public void actionPerformed(@NotNull final AnActionEvent e) {
    Project project = e.getData(CommonDataKeys.PROJECT);
    project = (project == null) ? ProjectManager.getInstance().getDefaultProject() : project;
    myProvider.doCheckout(project, getListener(project));
  }

  protected CheckoutProvider.Listener getListener(Project project) {
    return ProjectLevelVcsManager.getInstance(project).getCompositeCheckoutListener();
  }

  @Override
  public String getId() {
    return myIdPrefix + "." + myProvider.getVcsName().replaceAll("_", "");
  }
}
